@@ -314,11 +314,34 @@ class TLSTransport:
         )
         ctx.set_max_proto_version(tls_version)
         ctx.set_ocsp_client_callback(self._ocsp_handler)
-        ctx.set_options(
-            _util.lib.SSL_OP_ALLOW_UNSAFE_LEGACY_RENEGOTIATION
-            | _util.lib.SSL_OP_LEGACY_SERVER_CONNECT
-            | _util.lib.SSL_OP_TLS_ROLLBACK_BUG
-        )
+        if hasattr(_util.lib, 'SSL_OP_ALLOW_UNSAFE_LEGACY_RENEGOTIATION') and hasattr(_util.lib, 'SSL_OP_LEGACY_SERVER_CONNECT') and hasattr(_util.lib, 'SSL_OP_TLS_ROLLBACK_BUG'):
+            ctx.set_options(
+                _util.lib.SSL_OP_ALLOW_UNSAFE_LEGACY_RENEGOTIATION
+                | _util.lib.SSL_OP_LEGACY_SERVER_CONNECT
+                | _util.lib.SSL_OP_TLS_ROLLBACK_BUG
+            )
+        elif hasattr(_util.lib, 'SSL_OP_ALLOW_UNSAFE_LEGACY_RENEGOTIATION') and hasattr(_util.lib, 'SSL_OP_TLS_ROLLBACK_BUG'):
+            ctx.set_options(
+                _util.lib.SSL_OP_ALLOW_UNSAFE_LEGACY_RENEGOTIATION
+                | _util.lib.SSL_OP_TLS_ROLLBACK_BUG
+            )
+        elif hasattr(_util.lib, 'SSL_OP_ALLOW_UNSAFE_LEGACY_RENEGOTIATION') and hasattr(_util.lib, 'SSL_OP_LEGACY_SERVER_CONNECT'):
+            ctx.set_options(
+                _util.lib.SSL_OP_ALLOW_UNSAFE_LEGACY_RENEGOTIATION
+                | _util.lib.SSL_OP_LEGACY_SERVER_CONNECT
+            )
+        elif hasattr(_util.lib, 'SSL_OP_LEGACY_SERVER_CONNECT') and hasattr(_util.lib, 'SSL_OP_TLS_ROLLBACK_BUG'):
+            ctx.set_options(
+                _util.lib.SSL_OP_LEGACY_SERVER_CONNECT
+                | _util.lib.SSL_OP_TLS_ROLLBACK_BUG
+            )
+        elif hasattr(_util.lib, 'SSL_OP_ALLOW_UNSAFE_LEGACY_RENEGOTIATION'):
+            ctx.set_options(_util.lib.SSL_OP_ALLOW_UNSAFE_LEGACY_RENEGOTIATION)
+        elif hasattr(_util.lib, 'SSL_OP_LEGACY_SERVER_CONNECT'):
+            ctx.set_options(_util.lib.SSL_OP_LEGACY_SERVER_CONNECT)
+        elif hasattr(_util.lib, 'SSL_OP_TLS_ROLLBACK_BUG'):
+            ctx.set_options(_util.lib.SSL_OP_TLS_ROLLBACK_BUG)
+
         conn = SSL.Connection(context=ctx, socket=self.prepare_socket())
         conn.request_ocsp()
         if all([use_sni, ssl.HAS_SNI]):
@@ -405,11 +428,34 @@ class TLSTransport:
             raise TypeError(f"response_wait {type(response_wait)}, int supported")
         protocol = None
         ctx = self.prepare_context()
-        ctx.set_options(
-            _util.lib.SSL_OP_ALLOW_UNSAFE_LEGACY_RENEGOTIATION
-            | _util.lib.SSL_OP_LEGACY_SERVER_CONNECT
-            | _util.lib.SSL_OP_TLS_ROLLBACK_BUG
-        )
+        if hasattr(_util.lib, 'SSL_OP_ALLOW_UNSAFE_LEGACY_RENEGOTIATION') and hasattr(_util.lib, 'SSL_OP_LEGACY_SERVER_CONNECT') and hasattr(_util.lib, 'SSL_OP_TLS_ROLLBACK_BUG'):
+            ctx.set_options(
+                _util.lib.SSL_OP_ALLOW_UNSAFE_LEGACY_RENEGOTIATION
+                | _util.lib.SSL_OP_LEGACY_SERVER_CONNECT
+                | _util.lib.SSL_OP_TLS_ROLLBACK_BUG
+            )
+        elif hasattr(_util.lib, 'SSL_OP_ALLOW_UNSAFE_LEGACY_RENEGOTIATION') and hasattr(_util.lib, 'SSL_OP_TLS_ROLLBACK_BUG'):
+            ctx.set_options(
+                _util.lib.SSL_OP_ALLOW_UNSAFE_LEGACY_RENEGOTIATION
+                | _util.lib.SSL_OP_TLS_ROLLBACK_BUG
+            )
+        elif hasattr(_util.lib, 'SSL_OP_ALLOW_UNSAFE_LEGACY_RENEGOTIATION') and hasattr(_util.lib, 'SSL_OP_LEGACY_SERVER_CONNECT'):
+            ctx.set_options(
+                _util.lib.SSL_OP_ALLOW_UNSAFE_LEGACY_RENEGOTIATION
+                | _util.lib.SSL_OP_LEGACY_SERVER_CONNECT
+            )
+        elif hasattr(_util.lib, 'SSL_OP_LEGACY_SERVER_CONNECT') and hasattr(_util.lib, 'SSL_OP_TLS_ROLLBACK_BUG'):
+            ctx.set_options(
+                _util.lib.SSL_OP_LEGACY_SERVER_CONNECT
+                | _util.lib.SSL_OP_TLS_ROLLBACK_BUG
+            )
+        elif hasattr(_util.lib, 'SSL_OP_ALLOW_UNSAFE_LEGACY_RENEGOTIATION'):
+            ctx.set_options(_util.lib.SSL_OP_ALLOW_UNSAFE_LEGACY_RENEGOTIATION)
+        elif hasattr(_util.lib, 'SSL_OP_LEGACY_SERVER_CONNECT'):
+            ctx.set_options(_util.lib.SSL_OP_LEGACY_SERVER_CONNECT)
+        elif hasattr(_util.lib, 'SSL_OP_TLS_ROLLBACK_BUG'):
+            ctx.set_options(_util.lib.SSL_OP_TLS_ROLLBACK_BUG)
+
         try:
             if min_tls_version is not None:
                 logger.info(
